pub trait ConstTranscribable: GenTranscribable {
const NUM_BYTES: usize;
const NUM_BITS: usize = _;
}Expand description
If number of bytes for Transcribable is known at compile time,
there’s no need to read and write them from a buffer.
Required Associated Constants
Provided Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.